@@ -123,6 +123,12 @@ data = {
                         "action": "store_true",
                         "help": "retry last commit",
                     },
+                    {
+                        "name": ["--no-retry"],
+                        "action": "store_true",
+                        "default": False,
+                        "help": "skip retry if retry_after_failure is set to true",
+                    },
                     {
                         "name": "--dry-run",
                         "action": "store_true",
@@ -230,6 +236,19 @@ data = {
                         "choices": ["MAJOR", "MINOR", "PATCH"],
                         "type": str.upper,
                     },
+                    {
+                        "name": ["--increment-mode"],
+                        "choices": ["linear", "exact"],
+                        "default": "linear",
+                        "help": (
+                            "set the method by which the new version is chosen. "
+                            "'linear' (default) guesses the next version based on typical linear version progression, "
+                            "such that bumping of a pre-release with lower precedence than the current pre-release "
+                            "phase maintains the current phase of higher precedence. "
+                            "'exact' applies the changes that have been specified (or determined from the commit log) "
+                            "without interpretation, such that the increment and pre-release are always honored"
+                        ),
+                    },
                     {
                         "name": ["--check-consistency", "-cc"],
                         "help": (
@@ -308,6 +327,11 @@ data = {
                         "help": "bump to the given version (e.g: 1.5.3)",
                         "metavar": "MANUAL_VERSION",
                     },
+                    {
+                        "name": ["--build-metadata"],
+                        "help": "Add additional build-metadata to the version-number",
+                        "default": None,
+                    },
                 ],
             },
             {
